from dotenv import load_dotenv
import os
import json

load_dotenv()

# Code info
project = os.getenv('PROJECT')
company = os.getenv('COMPANY')
location = os.getenv('LOCATION')
dev = os.getenv('DEV')

# Database info
user = os.getenv('DB_USER')
password = os.getenv('DB_PASSWORD')
host = os.getenv('DB_HOST')
database = os.getenv('DB_DATABASE')

# Email info
email = os.getenv('EMAIL')
email_password = os.getenv('EMAIL_PASSWORD')

if not project or not company or not location or not dev:
    raise Exception("Por favor, as informações do código não podem ficar em branco.")

if not user or not password or not host or not database:
    raise Exception("Por favor, as informações do banco de dados não podem ficar em branco.")



from datetime import datetime
import sys
import os

from monit import config
from monit import func
from monit.database import Database, DataManager, Table

DB_URL = f'mysql+pymysql://{config.user}:{config.password}@{config.host}/{config.database}'

class DatabaseManager:
    def __init__(self, db_url):
        self.db = Database(db_url)
        self.data_manager = DataManager(self.db)

    def insert_data(self, data):
        id = self.data_manager.insert(data)
        return id

    def close(self):
        self.data_manager.close()


class Monitor:
    def __init__(self):
        if not os.path.exists('.env'):
                raise FileNotFoundError("Arquivo .env não encontrado. Por favor, crie um arquivo .env com as configurações necessárias.")

        self.init_time = datetime.now()
        self.db_manager = DatabaseManager(DB_URL)

        self.type = ""
        self.error = ""

    def register(self, type=None, err=None):
        table = func.build_table(type, err, Table(), self.init_time)
        self.db_manager.insert_data(table)

    def end(self):
        self.register(self.type, self.error)
        self.db_manager.close()

    def notify(self, type=None, error=None):
        self.type = type
        self.error = error
        # self.register(type, error)

    def notify_and_exit(self, type=None, error=None):
        self.register(type, error)
        self.db_manager.close()
        sys.exit(1)



from setuptools import setup, find_packages
import pathlib

setup(
    name='monit-agd',
    version='1.3.0',
    description='Programa de monitoramento de código python, desenvolvido para ser utilizado pelas funcionário da Agência de dados',
    long_description=pathlib.Path('README.md').read_text(),
    long_description_content_type='text/markdown',
    author='arktnld',
    author_email='arktnld@gmail.com',
    url='https://github.com/arktnld/monit',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'sqlalchemy',
        'pymysql',
        'psutil',
        'python-dotenv'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
